<?php

namespace App\Http\Controllers;

use App\Models\AppSession;
use App\Models\PotentialPro;
use App\Models\Pro;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Cookie;

class LoginController extends Controller
{
    
    public function login(Request $request){
        return view('login');
    }

    public function sendSmsAuthToken(Request $request){
        $cellNumber = $request->get('cell_number');
        $cellNumber = preg_replace("/[^0-9]/", "", $cellNumber);

        
        $request->validate([
            'g-recaptcha-response' => 'required|recaptcha'
        ]);

        $javaResponse = $this->callJava($request, '/potentialPro/createAndSendSmsAuthToken', [
            'cellNumber'=>$cellNumber
        ]);


        if(!$javaResponse['success']){
            return redirect()->back()->withInput($request->input())->with('message', $javaResponse['message']);
        }
        
        Cookie::queue('current_cell_number', $cellNumber, 300);
        return redirect()->to(route('confirm-auth-token'));
    }

    public function confirmAuthToken(Request $request){
        return view('confirm-auth-token');
    }

    public function processConfirmAuthToken(Request $request){
        $confirmationToken = $request->get('confirmation_token');
        $cellNumber = $request->cookie('current_cell_number');

        $javaResponse = $this->callJava($request, '/potentialPro/confirmSmsAuthToken', [
            'confirmationToken'=>$confirmationToken,
            'cellNumber' => $cellNumber,
        ]);

        if(!$javaResponse['success']){
            return redirect()->back()->withInput($request->input())->with('message', $javaResponse['message']);
        }
        
        Cookie::queue('current_confirmation_token', $confirmationToken, 300);

        $potentialPro = PotentialPro::where('cell_number_confirmation_token', $confirmationToken)->first(); 
        
        //if potential pro -> pro-details 
        if($potentialPro){
            return redirect()->to(route('pro-details'));
        }
    
        $existingPro = Pro::where('cell_number', $cellNumber)->first();
        $existingProAppSession = AppSession::where('pro_id', $existingPro->id)->where('two_step_sms_auth_token', $confirmationToken)->first();
        return redirect()->to(config('stag.authUrl').'/pro_log_in_with_session_key/'.$existingProAppSession->session_key);
    }

    public function proDetails(Request $request){
        $cellNumber = $request->cookie('current_cell_number');
        $token = $request->cookie('current_confirmation_token');
        $potentialPro = PotentialPro::where('cell_number_confirmation_token', $token)->get();
        if(!$potentialPro){
            return redirect()->to(route('confirm-password'));
        } 
        return view('pro-details');
    }
    
    //submitProDetails -> setup security questions  //create the actual pro and log the pro in without security questions set
    public function submitProDetails(Request $request){
        $request->validate([
            'first_name'=>'required',
            'last_name'=>'required',
            'email_address' => 'required|email',
            'password'=>'required'
        ]);

        $cellNumber = $request->cookie('current_cell_number');
        $token = $request->cookie('current_confirmation_token');
        $potentialPro = PotentialPro::where('cell_number_confirmation_token', $token)->get();
        if(!$potentialPro){
            abort(404, 'Not found');
        } 

        $javaResponse = $this->callJava($request, '/session/proLogInAsPotentialPro', [
            'confirmationToken'=>$token,
            'cellNumber' => $cellNumber,
            'firstName' => $request->get('first_name'),
            'lastName' => $request->get('last_name'),
            'emailAddress' => $request->get('email_address'),
            'password'=>$request->get('password'),
        ]);

        if(!$javaResponse['success']){
            return redirect()->back()->withInput($request->input())->with('message', $javaResponse['message']);
        }

        $proSessionKey = $javaResponse['data'];
        return redirect()->to(config('stag.authUrl').'/pro_log_in_with_session_key/'.$proSessionKey);
    }
    
}
